========================
Bluesky Queue Server API
========================

.. image:: https://img.shields.io/pypi/v/bluesky-queueserver-api.svg
        :target: https://pypi.python.org/pypi/bluesky-queueserver-api


Python API for Bluesky Queue Server

The project is currently containing a prototype of the API, which can change at any moment.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://bluesky.github.io/bluesky-queueserver-api.
